pub struct R(_);
Register CTRL reader
CTRL
Bit 0 - parallel if enable
Bit 1 - parallel if dma enable
Bit 2 - parallel if transmit software trigger
Bit 3 - parallel if all clear
Bit 4 - parallel if tx and rx logic clear, high action
Reads raw bits from register.
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
From<T> for U